// Defining base pathes
var paths = {
	styles: './assets/styles',
    scripts: './assets/scripts',
	dev_styles: './development/styles',
	dev_scripts: './development/scripts',
};

// Defining requirements
var gulp = require( 'gulp' );
var plumber = require( 'gulp-plumber' );
var sass = require( 'gulp-sass' );
var babel = require( 'gulp-babel' );
var postcss = require( 'gulp-postcss' );
var rename = require( 'gulp-rename' );
var concat = require( 'gulp-concat' );
var uglify = require( 'gulp-uglify' );
var sourcemaps = require( 'gulp-sourcemaps' );
var del = require( 'del' );
var cleanCSS = require( 'gulp-clean-css' );
var autoprefixer = require( 'autoprefixer' );


/**
 * Compiles .scss to .css files.
 *
 * Run: gulp styles
 */
gulp.task( 'styles', function() {
	return gulp
		.src( paths.dev_styles + '/*.scss' )
		.pipe(
			plumber( {
				errorHandler( err ) {
					console.log( err );
					this.emit( 'end' );
				},
			} )
		)
		.pipe( sourcemaps.init( { loadMaps: true } ) )
		.pipe( sass( { errLogToConsole: true } ) )
		.pipe( postcss( [ autoprefixer() ] ) )
		.pipe( sourcemaps.write( undefined, { sourceRoot: null } ) )
		.pipe( gulp.dest( paths.styles ) );
} );

/**
 * Minifies css files.
 *
 * Run: gulp minify-styles
 */
gulp.task( 'minify-styles', function() {
	return gulp
		.src( [
			paths.styles + '/borderless.css',
			paths.styles + '/dashboard.css',
			paths.styles + '/elementor.css',
			paths.styles + '/wpbakery.css',
		] )
		.pipe(
			sourcemaps.init( {
				loadMaps: true,
			} )
		)
		.pipe(
			cleanCSS( {
				compatibility: '*',
			} )
		)
		.pipe(
			plumber( {
				errorHandler( err ) {
					console.log( err );
					this.emit( 'end' );
				},
			} )
		)
		.pipe( rename( { suffix: '.min' } ) )
		.pipe( sourcemaps.write( './' ) )
		.pipe( gulp.dest( paths.styles ) );
} );

/**
 * Delete minified CSS files and their maps
 *
 * Run: gulp clean-styles
 */
gulp.task( 'clean-styles', function() {
	return del( paths.styles + '/*.min.css*' );
} );

/**
 * Compiles .scss to .css minifies css files.
 *
 * Run: gulp compile-styles
 */
gulp.task( 'compile-styles', function( callback ) {
	gulp.series( 'styles', 'minify-styles' )( callback );
} );

/**
 * Watches .scss, .js and image files for changes.
 * On change re-runs corresponding build task.
 * 
 * Run: gulp watch
 */
gulp.task( 'watch', function() {
	gulp.watch(
		[ 
			paths.dev_styles + '/**/*.scss',
			paths.dev_styles + '/*.scss'
		],
		gulp.series( 'compile-styles' )
	);
	gulp.watch(
		[	
			paths.dev_scripts + '/*.js',
			'!js/borderless.js',
			'!js/borderless.min.js',
		],
		gulp.series( 'scripts' )
	);
} );

// Run:
// gulp scripts.
// Uglifies and concat all JS files into one
gulp.task( 'scripts', function() {
	var scripts = [
		paths.dev_scripts + '/appear.min.js',
		paths.dev_scripts + '/countto.min.js',
		paths.dev_scripts + '/flickity.min.js',
		paths.dev_scripts + '/isotope.min.js',
		paths.dev_scripts + '/progressbar.js',
		paths.dev_scripts + '/borderless.js',
	];
	gulp
		.src( scripts, { allowEmpty: true } )
		.pipe( babel( { presets: ['@babel/preset-env'] } ) )
		.pipe( concat( 'borderless.min.js' ) )
		.pipe( uglify() )
		.pipe( gulp.dest( paths.scripts ) );

	return gulp
		.src( scripts, { allowEmpty: true } )
		.pipe( babel() )
		.pipe( concat( 'borderless.js' ) )
		.pipe( gulp.dest( paths.scripts ) );
} );

// Run:
// gulp
// Starts watcher (default task)
gulp.task( 'compile', gulp.series( 'watch' ) );